
<p align="center">
  <a href="https://gallery.stairlab.io/">
    <img src="https://veux.io/_static/images/stairlab_large.svg" alt="STAIRLab logo" width="200" height="165">
  </a>
</p>

<h3 align="center">xcsi</h3>


<p align="center">
Build finite element models for OpenSees and Xara from CSiBridge and SAP2000 input files.
  <br>
  <a href="https://gallery.stairlab.io/"><strong>Explore the STAIRLab gallery »</strong></a>
</p>


## Support

<table align="center">
<tr>
  <td>
    <a href="https://github.com/stairlab">
    STAIRlab (STructural Artificial Intelligence Research Lab)
    </a>
  </td>

  <td>
    <a href="https://peer.berkeley.edu">
    PEER (Pacific Earthquake Engineering Research Center)
    </a>
  </td>

  <td>
    <a href="https://dot.ca.gov/">
    Caltrans (California Department of Transportation)
    </a>
  </td>

  <td>
    <a href="https://peer.berkeley.edu">
    BRACE2 (Bridge Rapid Assessment Center for Extreme Events)
    </a>
  </td>

  <td>
    <a href="https://www.nsfgrfp.org/">
    NSF (National Science Foundation) GRFP (Graduate Research Fellowship Program)
    </a>
  </td>

</tr>

<tr>
  <td align="center">
    <a href="https://github.com/stairlab">
    <img src="https://raw.githubusercontent.com/chrystalchern/mdof/master/docs/_static/images/logos/stairlab.svg"
         alt="PEER Logo" height="120px"/>
    </a>
  </td>

  <td align="center">
    <a href="https://peer.berkeley.edu">
    <img src="https://raw.githubusercontent.com/chrystalchern/mdof/master/docs/assets/PEER_logo_old.svg"
         alt="PEER Logo" height="120px"/>
    </a>
  </td>

  <td align="center">
    <a href="https://dot.ca.gov/">
    <img src="https://raw.githubusercontent.com/claudioperez/sdof/master/docs/assets/Caltrans.svg.png"
         alt="Caltrans Logo" height="120px"/>
    </a>
  </td>

  <td align="center">
    <a href="https://peer.berkeley.edu">
    <img src="https://raw.githubusercontent.com/claudioperez/sdof/master/docs/assets/brace2_logo-new3_ungrouped.svg"
         alt="BRACE2 Logo" height="120px"/>
    </a>
  </td>

  <td align="center">
    <a href="https://www.nsfgrfp.org/">
    <img src="https://raw.githubusercontent.com/chrystalchern/mdof/master/docs/_static/images/logos/nsf_logo.jpg"
         alt="NSF Logo" height="120px"/>
    </a>
  </td>
 
</tr>
</table>


